@@ -6,7 +6,7 @@ import random
 import argparse
 
 
-def get_options():
+def _get_options():
     parser = argparse.ArgumentParser()
     parser.add_argument('-s', '--sides', default=6, type=int)
     parser.add_argument('number', nargs='?', type=int, default=1)
@@ -28,11 +28,21 @@ class Dice(object):
         return random.randint(1, self.sides)
 
 
-def do_dice_roll():
+def main():
     """
-    Roll n-sided dice and return each result and the total
+    Roll n-sided dice and return each result and the total.
+
+    >>> monkeypatch = getfixture('monkeypatch')
+    >>> monkeypatch.setattr('sys.argv', ['roll-dice'])
+    >>> main()
+    rolled ...
+    >>> monkeypatch.setattr('sys.argv', ['roll-dice', '2'])
+    >>> main()
+    rolled ...
+    rolled ...
+    total ...
     """
-    options = get_options()
+    options = _get_options()
     dice = Dice(options.sides)
     rolls = [dice.roll() for n in range(options.number)]
     for roll in rolls:
@@ -41,4 +51,4 @@ def do_dice_roll():
         print('total', sum(rolls))
 
 
-__name__ == '__main__' and do_dice_roll()
+__name__ == '__main__' and main()
