@@ -5,13 +5,13 @@ import queue
 
 
 def enqueue_lines(stream, queue):
-    for line in iter(stream.readline, b''):
+    for line in iter(stream.readline, ''):
         queue.put(line)
     stream.close()
 
 
 def Popen_nonblocking(*args, **kwargs):
-    """
+    r"""
     Open a subprocess without blocking. Return a process handle with any
     output streams replaced by queues of lines from that stream.
 
@@ -24,9 +24,22 @@ def Popen_nonblocking(*args, **kwargs):
             "no output available"
         else:
             handle_output(out_line)
+
+    ### import contextlib
+    >>> proc = Popen_nonblocking(
+    ...     [sys.executable, '-c', 'print("hello world")'],
+    ...     stdout=subprocess.PIPE,
+    ...     stderr=subprocess.PIPE,
+    ... )
+    >>> proc.wait()
+    0
+    >>> proc.stdout.get()
+    'hello world\n'
     """
     kwargs.setdefault('close_fds', 'posix' in sys.builtin_module_names)
     kwargs.setdefault('bufsize', 1)
+    text_setting = ['universal_newlines', 'text'][sys.version_info > (3, 7)]
+    kwargs.setdefault(text_setting, True)
     proc = subprocess.Popen(*args, **kwargs)
     if proc.stdout:
         q = queue.Queue()
